@@ -54,7 +54,11 @@ class Descriptor(Description, Message, Code[CodeT], Generic[CodeT]):
 
 
 class Order(BaseModel):
-    order: OptionalInteger = Field(..., description="Order")
+    order: int = Field(..., ge=1, description="Order")
+
+
+class OptionalOrder(BaseModel):
+    order: OptionalInteger = Field(None, ge=1, description="Order. (Optional)")
 
 
 class Key(BaseModel):
