@@ -1,33 +1,23 @@
 from typing import Generic
 from maleo.soma.mixins.parameter import (
     IdentifierTypeT,
-    IdentifierType,
     IdentifierValueT,
-    IdentifierValue,
+    IdentifierTypeValue,
     OptionalListOfDataStatuses,
     UseCache,
 )
 
 
 class ReadSingleQueryParameterSchema(
+    UseCache,
     OptionalListOfDataStatuses,
-    UseCache,
-):
-    pass
-
-
-class BaseReadSingleParameterSchema(
-    UseCache,
-    IdentifierValue[IdentifierValueT],
-    IdentifierType[IdentifierTypeT],
-    Generic[IdentifierTypeT, IdentifierValueT],
 ):
     pass
 
 
 class ReadSingleParameterSchema(
-    OptionalListOfDataStatuses,
-    BaseReadSingleParameterSchema[IdentifierTypeT, IdentifierValueT],
+    ReadSingleQueryParameterSchema,
+    IdentifierTypeValue[IdentifierTypeT, IdentifierValueT],
     Generic[IdentifierTypeT, IdentifierValueT],
 ):
     pass
